
class Calculator:

    @staticmethod
    def add(a, b):
        """
        Generate addition of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: sum of a and b
        """

        return a + b

    @staticmethod
    def sub(a, b):
        """
        Generate subtraction of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: subtract b from a
        """

        return a - b

    @staticmethod
    def mul(a, b):
        """
        Generate multiplication of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: multiplication of a and b
        """

        return a * b

    @staticmethod
    def div(a, b):
        """
        Generate division of two input parameters

        :param a: first input variable
        :param b: second input variable
        :return: Divide a by b
        """

        return a / b
